AdminLTE 3 | Simple Tables

# Simple Tables

### Bordered Table

# | Task | Progress | Label
--- | --- | --- | ---
1. | Update software |  | 55%
2. | Clean database |  | 70%
3. | Cron job running |  | 30%
4. | Fix and squish bugs |  | 90%

### Condensed Full Width Table

# | Task | Progress | Label
--- | --- | --- | ---
1. | Update software |  | 55%
2. | Clean database |  | 70%
3. | Cron job running |  | 30%
4. | Fix and squish bugs |  | 90%

### Simple Full Width Table

- «
- 1
- 2
- 3
- »

# | Task | Progress | Label
--- | --- | --- | ---
1. | Update software |  | 55%
2. | Clean database |  | 70%
3. | Cron job running |  | 30%
4. | Fix and squish bugs |  | 90%

### Striped Full Width Table

# | Task | Progress | Label
--- | --- | --- | ---
1. | Update software |  | 55%
2. | Clean database |  | 70%
3. | Cron job running |  | 30%
4. | Fix and squish bugs |  | 90%

### Responsive Hover Table

ID | User | Date | Status | Reason
--- | --- | --- | --- | ---
183 | John Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
219 | Alexander Pierce | 11-7-2014 | Pending | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
657 | Bob Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
175 | Mike Doe | 11-7-2014 | Denied | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.

### Fixed Header Table

ID | User | Date | Status | Reason
--- | --- | --- | --- | ---
183 | John Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
219 | Alexander Pierce | 11-7-2014 | Pending | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
657 | Bob Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
175 | Mike Doe | 11-7-2014 | Denied | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
134 | Jim Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
494 | Victoria Doe | 11-7-2014 | Pending | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
832 | Michael Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
982 | Rocky Doe | 11-7-2014 | Denied | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.

### Expandable Table

# | User | Date | Status | Reason
--- | --- | --- | --- | ---
183 | John Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
219 | Alexander Pierce | 11-7-2014 | Pending | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
657 | Alexander Pierce | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
175 | Mike Doe | 11-7-2014 | Denied | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
134 | Jim Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
494 | Victoria Doe | 11-7-2014 | Pending | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
832 | Michael Doe | 11-7-2014 | Approved | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.
982 | Rocky Doe | 11-7-2014 | Denied | Bacon ipsum dolor sit amet salami venison chicken flank fatback doner.
Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. It was popularised in the 1960s with the release of Letraset sheets containing Lorem Ipsum passages, and more recently with desktop publishing software like Aldus PageMaker including versions of Lorem Ipsum.

### Expandable Table Tree

183
219
219-1
219-1-1
219-1-2
219-1-3
219-2
219-2-1
219-2-2
219-2-3
219-3
657
175
134
494
832
982